summaryrefslogtreecommitdiff
path: root/nsswitch
diff options
context:
space:
mode:
authorMichael Adam <obnox@samba.org>2009-01-22 13:57:21 +0100
committerMichael Adam <obnox@samba.org>2010-08-14 02:10:33 +0200
commit1ac8bf4ea8f28bf39990c42449eda07966bd5f81 (patch)
tree85f4abb75b6931a40d1ebdd3f6f8b77076b9dfc2 /nsswitch
parent89100cb509dadeb0f9905f15ea8a631094e3f052 (diff)
downloadsamba-1ac8bf4ea8f28bf39990c42449eda07966bd5f81.tar.gz
samba-1ac8bf4ea8f28bf39990c42449eda07966bd5f81.tar.bz2
samba-1ac8bf4ea8f28bf39990c42449eda07966bd5f81.zip
libwbclient: unimplement wbcRemoveGidMapping()
Michael
Diffstat (limited to 'nsswitch')
-rw-r--r--nsswitch/libwbclient/wbc_idmap.c35
1 files changed, 2 insertions, 33 deletions
diff --git a/nsswitch/libwbclient/wbc_idmap.c b/nsswitch/libwbclient/wbc_idmap.c
index 773bc94dfb..ab8de9f973 100644
--- a/nsswitch/libwbclient/wbc_idmap.c
+++ b/nsswitch/libwbclient/wbc_idmap.c
@@ -289,41 +289,10 @@ wbcErr wbcRemoveUidMapping(uid_t uid, const struct wbcDomainSid *sid)
return WBC_ERR_NOT_IMPLEMENTED;
}
/* Remove a group id mapping */
wbcErr wbcRemoveGidMapping(gid_t gid, const struct wbcDomainSid *sid)
{
- struct winbindd_request request;
- struct winbindd_response response;
- wbcErr wbc_status = WBC_ERR_UNKNOWN_FAILURE;
- char *sid_string = NULL;
-
- if (!sid) {
- return WBC_ERR_INVALID_PARAM;
- }
-
- /* Initialise request */
-
- ZERO_STRUCT(request);
- ZERO_STRUCT(response);
-
- /* Make request */
-
- request.data.dual_idmapset.id = gid;
- request.data.dual_idmapset.type = _ID_TYPE_GID;
-
- wbc_status = wbcSidToString(sid, &sid_string);
- BAIL_ON_WBC_ERROR(wbc_status);
-
- strncpy(request.data.dual_idmapset.sid, sid_string,
- sizeof(request.data.dual_idmapset.sid)-1);
- wbcFreeMemory(sid_string);
-
- wbc_status = wbcRequestResponsePriv(WINBINDD_REMOVE_MAPPING,
- &request, &response);
- BAIL_ON_WBC_ERROR(wbc_status);
-
- done:
- return wbc_status;
+ return WBC_ERR_NOT_IMPLEMENTED;
}
/* Set the highwater mark for allocated uids - not implemented any more */
@@ -289,41 +289,10 @@ wbcErr wbcRemoveUidMapping(uid_t uid, const struct wbcDomainSid *sid)
return WBC_ERR_NOT_IMPLEMENTED;
}
-/* Remove a group id mapping */
+/* Remove a group id mapping - not implemented any more */
wbcErr wbcRemoveGidMapping(gid_t gid, const struct wbcDomainSid *sid)
{